svn commit: r312234 - in head: sbin/camcontrol share/man/man4 share/man/man9 sys/arm/arm sys/arm/freescale/imx sys/arm/mv sys/cam sys/dev/bhnd sys/dev/fdt sys/dev/isp sys/dev/mmc sys/dev/mpt sys/de...

Conrad E. Meyer cem at FreeBSD.org
Sun Jan 15 17:54:07 UTC 2017


Author: cem
Date: Sun Jan 15 17:54:01 2017
New Revision: 312234
URL: https://svnweb.freebsd.org/changeset/base/312234

Log:
  "Buses" is the preferred plural of "bus"
  
  Replace archaic "busses" with modern form "buses."
  
  Intentionally excluded:
  * Old/random drivers I didn't recognize
    * Old hardware in general
  * Use of "busses" in code as identifiers
  
  No functional change.
  
  http://grammarist.com/spelling/buses-busses/
  
  PR:		216099
  Reported by:	bltsrc at mail.ru
  Sponsored by:	Dell EMC Isilon

Modified:
  head/sbin/camcontrol/camcontrol.8
  head/sbin/camcontrol/camcontrol.c
  head/share/man/man4/ehci.4
  head/share/man/man4/iicbus.4
  head/share/man/man4/scsi.4
  head/share/man/man9/BUS_CONFIG_INTR.9
  head/share/man/man9/DEVICE_ATTACH.9
  head/share/man/man9/DEVICE_IDENTIFY.9
  head/share/man/man9/DRIVER_MODULE.9
  head/share/man/man9/bus_generic_attach.9
  head/share/man/man9/bus_generic_detach.9
  head/share/man/man9/bus_generic_new_pass.9
  head/share/man/man9/bus_generic_print_child.9
  head/share/man/man9/bus_generic_read_ivar.9
  head/share/man/man9/bus_generic_shutdown.9
  head/share/man/man9/bus_space.9
  head/share/man/man9/device.9
  head/share/man/man9/device_add_child.9
  head/share/man/man9/pci.9
  head/sys/arm/arm/ofw_machdep.c
  head/sys/arm/freescale/imx/imx6_ccm.c
  head/sys/arm/freescale/imx/imx6_machdep.c
  head/sys/arm/freescale/imx/imx_i2c.c
  head/sys/arm/mv/mv_pci.c
  head/sys/cam/cam_xpt.c
  head/sys/cam/cam_xpt_internal.h
  head/sys/dev/bhnd/bhnd.h
  head/sys/dev/fdt/simplebus.c
  head/sys/dev/isp/isp.c
  head/sys/dev/mmc/mmcreg.h
  head/sys/dev/mpt/mpt.c
  head/sys/dev/mpt/mpt.h
  head/sys/dev/mpt/mpt_raid.c
  head/sys/dev/pccbb/pccbb_pci.c
  head/sys/dev/pci/hostb_pci.c
  head/sys/dev/pci/pci.c
  head/sys/dev/pci/pci_private.h
  head/sys/dev/pci/pci_subr.c
  head/sys/dev/usb/usb_hub.c
  head/sys/kern/bus_if.m
  head/sys/kern/sched_ule.c
  head/sys/kern/subr_bus.c
  head/sys/sys/bus.h
  head/sys/x86/pci/pci_bus.c
  head/sys/x86/x86/mptable.c
  head/sys/x86/x86/nexus.c
  head/sys/xen/xenbus/xenbusb.c
  head/sys/xen/xenbus/xenbusb.h
  head/usr.sbin/mptutil/mpt_cam.c

Modified: head/sbin/camcontrol/camcontrol.8
==============================================================================
--- head/sbin/camcontrol/camcontrol.8	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sbin/camcontrol/camcontrol.8	Sun Jan 15 17:54:01 2017	(r312234)
@@ -27,7 +27,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd January 6, 2017
+.Dd January 15, 2017
 .Dt CAMCONTROL 8
 .Os
 .Sh NAME
@@ -565,12 +565,12 @@ start bit set and the load/eject bit set
 Send the SCSI Start/Stop Unit (0x1B) command to the given device with the
 start bit cleared and the load/eject bit set.
 .It Ic rescan
-Tell the kernel to scan all busses in the system (with the
+Tell the kernel to scan all buses in the system (with the
 .Ar all
 argument), the given bus (XPT_SCAN_BUS), or bus:target:lun
 (XPT_SCAN_LUN) for new devices or devices that have gone away.
 The user
-may specify a scan of all busses, a single bus, or a lun.
+may specify a scan of all buses, a single bus, or a lun.
 Scanning all luns
 on a target is not supported.
 .It Ic reprobe
@@ -580,7 +580,7 @@ notify the upper layer,
 This includes sending the SCSI READ CAPACITY command and updating
 the disk size visible to the rest of the system.
 .It Ic reset
-Tell the kernel to reset all busses in the system (with the
+Tell the kernel to reset all buses in the system (with the
 .Ar all
 argument) or the given bus (XPT_RESET_BUS) by issuing a SCSI bus
 reset for that bus, or to reset the given bus:target:lun
@@ -2557,7 +2557,7 @@ write reallocation settings, among other
 .Pp
 .Dl camcontrol rescan all
 .Pp
-Rescan all SCSI busses in the system for devices that have been added,
+Rescan all SCSI buses in the system for devices that have been added,
 removed or changed.
 .Pp
 .Dl camcontrol rescan 0

Modified: head/sbin/camcontrol/camcontrol.c
==============================================================================
--- head/share/man/man4/ehci.4	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man4/ehci.4	Sun Jan 15 17:54:01 2017	(r312234)
@@ -29,7 +29,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd March 4, 2012
+.Dd January 15, 2017
 .Dt EHCI 4
 .Os
 .Sh NAME
@@ -68,7 +68,7 @@ but can be noticed since
 1.x and
 .Tn USB
 2.0 devices plugged in to the same
-connector appear to connect to different USB busses.
+connector appear to connect to different USB buses.
 .Sh SEE ALSO
 .Xr ohci 4 ,
 .Xr uhci 4 ,

Modified: head/share/man/man4/iicbus.4
==============================================================================
--- head/share/man/man4/iicbus.4	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man4/iicbus.4	Sun Jan 15 17:54:01 2017	(r312234)
@@ -24,7 +24,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd November 17, 2014
+.Dd January 15, 2017
 .Dt IICBUS 4
 .Os
 .Sh NAME
@@ -112,11 +112,11 @@ different speed.
 A general purpose I2C bus, such as those found in many embedded systems,
 will often support multiple bus frequencies.
 .Pp
-When a system supports multiple I2C busses, a different frequency can
+When a system supports multiple I2C buses, a different frequency can
 be configured for each bus by number, represented by the
 .Va %d
 in the variable names below.
-Busses can be configured using any combination of device hints,
+Buses can be configured using any combination of device hints,
 Flattened Device Tree (FDT) data, tunables set via
 .Xr loader 8 ,
 or at runtime using

Modified: head/share/man/man4/scsi.4
==============================================================================
--- head/share/man/man4/scsi.4	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man4/scsi.4	Sun Jan 15 17:54:01 2017	(r312234)
@@ -24,7 +24,7 @@
 .\" SUCH DAMAGE.
 .\"
 .\" $FreeBSD$
-.Dd June 7, 2012
+.Dd January 15, 2017
 .Dt CAM 4
 .Os
 .Sh NAME
@@ -62,7 +62,7 @@ devices, and to utilize different
 and
 .Tn ATA
 host adapters through host adapter drivers.
-When the system probes busses, it attaches any devices it finds to the
+When the system probes buses, it attaches any devices it finds to the
 appropriate drivers.
 The
 .Xr pass 4
@@ -150,7 +150,7 @@ In that case, the
 will be reset to 100ms.
 .El
 .Pp
-All devices and busses support dynamic allocation so that
+All devices and buses support dynamic allocation so that
 an upper number of devices and controllers does not need to be configured;
 .Cd "device da"
 will suffice for any number of disk drivers.
@@ -297,7 +297,7 @@ see printfs for multiple debugging level
 This allows to set the various debugging flags from a kernel config file.
 .It Dv CAM_DEBUG_BUS
 Specify a bus to debug.
-To debug all busses, set this to -1.
+To debug all buses, set this to -1.
 .It Dv CAM_DEBUG_TARGET
 Specify a target to debug.
 To debug all targets, set this to -1.

Modified: head/share/man/man9/BUS_CONFIG_INTR.9
==============================================================================
--- head/share/man/man9/BUS_CONFIG_INTR.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/BUS_CONFIG_INTR.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -25,7 +25,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd January 6, 2005
+.Dd January 15, 2017
 .Dt BUS_CONFIG_INTR 9
 .Os
 .\"
@@ -45,7 +45,7 @@
 The
 .Fn BUS_CONFIG_INTR
 method allows bus or device drivers to provide interrupt polarity and trigger
-mode to parent busses.
+mode to parent buses.
 This typically bubbles all the way up to the root bus (e.g.\& nexus) where the
 necessary actions are taken to actually program the hardware.
 Since the

Modified: head/share/man/man9/DEVICE_ATTACH.9
==============================================================================
--- head/share/man/man9/DEVICE_ATTACH.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/DEVICE_ATTACH.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,7 +28,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd January 6, 2005
+.Dd January 15, 2017
 .Dt DEVICE_ATTACH 9
 .Os
 .Sh NAME
@@ -51,7 +51,7 @@ system resources (such as
 .Xr devfs 5
 entries).
 .Pp
-Devices which implement busses should use this method to probe for
+Devices which implement buses should use this method to probe for
 the existence of devices attached to the bus and add them as
 children.
 If this is combined with the use of

Modified: head/share/man/man9/DEVICE_IDENTIFY.9
==============================================================================
--- head/share/man/man9/DEVICE_IDENTIFY.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/DEVICE_IDENTIFY.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,7 +28,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd May 13, 2004
+.Dd January 15, 2017
 .Dt DEVICE_IDENTIFY 9
 .Os
 .Sh NAME
@@ -40,7 +40,7 @@
 .Ft void
 .Fn DEVICE_IDENTIFY "driver_t *driver" "device_t parent"
 .Sh DESCRIPTION
-The identify function for a device is only needed for devices on busses
+The identify function for a device is only needed for devices on buses
 that cannot identify their children independently, e.g.\& the ISA bus.
 It is used to recognize the device (usually done by accessing non-ambiguous
 registers in the hardware) and to tell the kernel about it and thus

Modified: head/share/man/man9/DRIVER_MODULE.9
==============================================================================
--- head/share/man/man9/DRIVER_MODULE.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/DRIVER_MODULE.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,7 +28,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd August 21, 2012
+.Dd January 15, 2017
 .Dt DRIVER_MODULE 9
 .Os
 .Sh NAME
@@ -69,9 +69,9 @@ or
 The identifier used in
 .Fn DRIVER_MODULE
 can be different from the driver name.
-Also, the same driver identifier can exist on different busses,
+Also, the same driver identifier can exist on different buses,
 which is a pretty clean way of making front ends for different cards
-using the same driver on the same or different busses.
+using the same driver on the same or different buses.
 For example, the following is allowed:
 .Pp
 .Fn DRIVER_MODULE foo isa foo_driver foo_devclass NULL NULL ;

Modified: head/share/man/man9/bus_generic_attach.9
==============================================================================
--- head/share/man/man9/bus_generic_attach.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_generic_attach.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,14 +28,14 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 16, 1998
+.Dd January 15, 2017
 .Dt BUS_GENERIC_ATTACH 9
 .Os
 .Sh NAME
 .Nm bus_generic_attach
 .Nd generic implementation of
 .Dv DEVICE_ATTACH
-for busses
+for buses
 .Sh SYNOPSIS
 .In sys/param.h
 .In sys/bus.h

Modified: head/share/man/man9/bus_generic_detach.9
==============================================================================
--- head/share/man/man9/bus_generic_detach.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_generic_detach.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,14 +28,14 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 16, 1998
+.Dd January 15, 2017
 .Dt BUS_GENERIC_DETACH 9
 .Os
 .Sh NAME
 .Nm bus_generic_detach
 .Nd generic implementation of
 .Dv DEVICE_DETACH
-for busses
+for buses
 .Sh SYNOPSIS
 .In sys/param.h
 .In sys/bus.h

Modified: head/share/man/man9/bus_generic_new_pass.9
==============================================================================
--- head/share/man/man9/bus_generic_new_pass.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_generic_new_pass.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -27,7 +27,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 8, 2009
+.Dd January 15, 2017
 .Dt BUS_GENERIC_NEW_PASS 9
 .Os
 .Sh NAME
@@ -47,7 +47,7 @@ It first invokes the
 method for any drivers whose pass level is equal to the new pass level.
 Then, for each attached child device it calls
 .Xr BUS_NEW_PASS 9
-to rescan child busses,
+to rescan child buses,
 and for each unattached child device it calls
 .Xr device_probe_and_attach 9 .
 .Sh SEE ALSO

Modified: head/share/man/man9/bus_generic_print_child.9
==============================================================================
--- head/share/man/man9/bus_generic_print_child.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_generic_print_child.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,14 +28,14 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 16, 1998
+.Dd January 15, 2017
 .Dt BUS_GENERIC_PRINT_CHILD 9
 .Os
 .Sh NAME
 .Nm bus_generic_print_child
 .Nd generic implementation of
 .Dv DEVICE_PRINT_CHILD
-for busses
+for buses
 .Sh SYNOPSIS
 .In sys/param.h
 .In sys/bus.h

Modified: head/share/man/man9/bus_generic_read_ivar.9
==============================================================================
--- head/share/man/man9/bus_generic_read_ivar.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_generic_read_ivar.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,7 +28,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 16, 1998
+.Dd January 15, 2017
 .Dt BUS_GENERIC_READ_IVAR 9
 .Os
 .Sh NAME
@@ -38,7 +38,7 @@
 .Dv BUS_READ_IVAR
 and
 .Dv BUS_WRITE_IVAR
-for busses
+for buses
 .Sh SYNOPSIS
 .In sys/param.h
 .In sys/bus.h

Modified: head/share/man/man9/bus_generic_shutdown.9
==============================================================================
--- head/share/man/man9/bus_generic_shutdown.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_generic_shutdown.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,14 +28,14 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 16, 1998
+.Dd January 15, 2017
 .Dt BUS_GENERIC_SHUTDOWN 9
 .Os
 .Sh NAME
 .Nm bus_generic_shutdown
 .Nd generic implementation of
 .Dv DEVICE_SHUTDOWN
-for busses
+for buses
 .Sh SYNOPSIS
 .In sys/param.h
 .In sys/bus.h

Modified: head/share/man/man9/bus_space.9
==============================================================================
--- head/share/man/man9/bus_space.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/bus_space.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -51,7 +51,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 13, 2005
+.Dd January 15, 2017
 .Dt BUS_SPACE 9
 .Os
 .Sh NAME
@@ -601,7 +601,7 @@ of devices on different system architect
 object file to manipulate a set of devices on multiple bus types on a
 single architecture.
 .Pp
-Not all busses have to implement all functions described in this
+Not all buses have to implement all functions described in this
 document, though that is encouraged if the operations are logically
 supported by the bus.
 Unimplemented functions should cause
@@ -625,7 +625,7 @@ machine-dependent code.
 A given machine may have several different types
 of bus space (e.g.\& memory space and I/O space), and thus may provide
 multiple different bus space tags.
-Individual busses or devices on a machine may use more than one bus space
+Individual buses or devices on a machine may use more than one bus space
 tag.
 For instance, ISA devices are
 given an ISA memory space tag and an ISA I/O space tag.
@@ -639,7 +639,7 @@ The
 bus address describes the start of the range in bus space.
 The bus
 size describes the size of the range in bytes.
-Busses which are not byte
+Buses which are not byte
 addressable may require use of bus space ranges with appropriately
 aligned addresses and properly rounded sizes.
 .Pp
@@ -656,7 +656,7 @@ argument, at least one handle argument, 
 The bus space tag specifies the space, each handle specifies a region in
 the space, and each offset specifies the offset into the region of the
 actual location(s) to be accessed.
-Offsets are given in bytes, though busses
+Offsets are given in bytes, though buses
 may impose alignment constraints.
 The offset used to access data
 relative to a given handle must be such that all of the data being
@@ -1049,7 +1049,7 @@ The
 and
 .Fn bus_space_write_N
 families of functions provide
-the ability to read and write 1, 2, 4, and 8 byte data items on busses
+the ability to read and write 1, 2, 4, and 8 byte data items on buses
 which support those access sizes.
 .Ss Fn bus_space_read_1 space handle offset
 .Ss Fn bus_space_read_2 space handle offset

Modified: head/share/man/man9/device.9
==============================================================================
--- head/share/man/man9/device.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/device.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,7 +28,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd June 16, 1998
+.Dd January 15, 2017
 .Dt DEVICE 9
 .Os
 .Sh NAME
@@ -44,7 +44,7 @@ The system defines one device,
 .Va root_bus
 and all other devices are created dynamically during
 autoconfiguration.
-Normally devices representing top-level busses in
+Normally devices representing top-level buses in
 the system (ISA, PCI etc.) will be attached directly to
 .Va root_bus
 and other devices will be added as children of their relevant bus.

Modified: head/share/man/man9/device_add_child.9
==============================================================================
--- head/share/man/man9/device_add_child.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/device_add_child.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -28,7 +28,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd October 28, 2015
+.Dd January 15, 2017
 .Dt DEVICE_ADD_CHILD 9
 .Os
 .Sh NAME
@@ -63,10 +63,10 @@ If no name is given then all drivers for
 In any event, only the name of the device is stored so that one may
 safely unload/load a driver bound to that name.
 .Pp
-This allows busses which can uniquely identify device instances (such
+This allows buses which can uniquely identify device instances (such
 as PCI) to allow each driver to check each device instance for a
 match.
-For busses which rely on supplied probe hints where only one
+For buses which rely on supplied probe hints where only one
 driver can have a chance of probing the device, the driver name should
 be specified as the device name.
 .Pp

Modified: head/share/man/man9/pci.9
==============================================================================
--- head/share/man/man9/pci.9	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/share/man/man9/pci.9	Sun Jan 15 17:54:01 2017	(r312234)
@@ -25,7 +25,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd September 6, 2016
+.Dd January 15, 2017
 .Dt PCI 9
 .Os
 .Sh NAME
@@ -583,14 +583,14 @@ full functionality to the user.
 .It Dv PCI_POWERSTATE_D1
 Class-specific low-power state in which device context may or
 may not be lost.
-Busses in this state cannot do anything to the bus, to
+Buses in this state cannot do anything to the bus, to
 force devices to lose context.
 .It Dv PCI_POWERSTATE_D2
 Class-specific low-power state in which device context may or
 may not be lost.
 Attains greater power savings than
 .Dv PCI_POWERSTATE_D1 .
-Busses in this state can cause devices to lose some context.
+Buses in this state can cause devices to lose some context.
 Devices
 .Em must
 be prepared for the bus to be in this state or higher.

Modified: head/sys/arm/arm/ofw_machdep.c
==============================================================================
--- head/sys/arm/arm/ofw_machdep.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/arm/arm/ofw_machdep.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -50,7 +50,7 @@ OF_decode_addr(phandle_t dev, int regno,
 		return (res);
 
 	/*
-	 * Nothing special to do for PCI busses right now.
+	 * Nothing special to do for PCI buses right now.
 	 * This may need to be handled per-platform when it does come up.
 	 */
 #ifdef notyet

Modified: head/sys/arm/freescale/imx/imx6_ccm.c
==============================================================================
--- head/sys/arm/freescale/imx/imx6_ccm.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/arm/freescale/imx/imx6_ccm.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -90,7 +90,7 @@ ccm_init_gates(struct ccm_softc *sc)
 {
 	uint32_t reg;
 
- 	/* ahpbdma, aipstz 1 & 2 busses */
+ 	/* ahpbdma, aipstz 1 & 2 buses */
 	reg = CCGR0_AIPS_TZ1 | CCGR0_AIPS_TZ2 | CCGR0_ABPHDMA;
 	WR4(sc, CCM_CCGR0, reg);
 

Modified: head/sys/arm/freescale/imx/imx6_machdep.c
==============================================================================
--- head/sys/arm/freescale/imx/imx6_machdep.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/arm/freescale/imx/imx6_machdep.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -117,7 +117,7 @@ fdt_pic_decode_t fdt_pic_table[] = {
  *  - GIC node exists and is its own interrupt parent.
  *
  * This applies to all models of imx6.  Luckily all of them have the devices
- * involved at the same addresses on the same busses, so we don't need any
+ * involved at the same addresses on the same buses, so we don't need any
  * per-soc logic.  We handle this at platform attach time rather than via the
  * fdt_fixup_table, because the latter requires matching on the FDT "model"
  * property, and this applies to all boards including those not yet invented.

Modified: head/sys/arm/freescale/imx/imx_i2c.c
==============================================================================
--- head/sys/arm/freescale/imx/imx_i2c.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/arm/freescale/imx/imx_i2c.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -35,7 +35,7 @@
  * Note that the hardware is capable of running as both a master and a slave.
  * This driver currently implements only master-mode operations.
  *
- * This driver supports multi-master i2c busses, by detecting bus arbitration
+ * This driver supports multi-master i2c buses, by detecting bus arbitration
  * loss and returning IIC_EBUSBSY status.  Notably, it does not do any kind of
  * retries if some other master jumps onto the bus and interrupts one of our
  * transfer cycles resulting in arbitration loss in mid-transfer.  The caller

Modified: head/sys/arm/mv/mv_pci.c
==============================================================================
--- head/sys/arm/mv/mv_pci.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/arm/mv/mv_pci.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -147,7 +147,7 @@ mv_pci_ranges_decode(phandle_t node, str
 	/*
 	 * Initialize the ranges so that we don't have to worry about
 	 * having them all defined in the FDT. In particular, it is
-	 * perfectly fine not to want I/O space on PCI busses.
+	 * perfectly fine not to want I/O space on PCI buses.
 	 */
 	bzero(io_space, sizeof(*io_space));
 	bzero(mem_space, sizeof(*mem_space));

Modified: head/sys/cam/cam_xpt.c
==============================================================================
--- head/sys/cam/cam_xpt.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/cam/cam_xpt.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -106,7 +106,12 @@ struct xpt_softc {
 	int buses_to_config;
 	int buses_config_done;
 
-	/* Registered busses */
+	/*
+	 * Registered buses
+	 *
+	 * N.B., "busses" is an archaic spelling of "buses".  In new code
+	 * "buses" is preferred.
+	 */
 	TAILQ_HEAD(,cam_eb)	xpt_busses;
 	u_int			bus_generation;
 
@@ -892,7 +897,7 @@ xpt_init(void *dummy)
 	/*
 	 * The xpt layer is, itself, the equivalent of a SIM.
 	 * Allow 16 ccbs in the ccb pool for it.  This should
-	 * give decent parallelism when we probe busses and
+	 * give decent parallelism when we probe buses and
 	 * perform other XPT functions.
 	 */
 	devq = cam_simq_alloc(16);
@@ -1627,7 +1632,7 @@ xptedtbusfunc(struct cam_eb *bus, void *
 	}
 
 	/*
-	 * If the user is only interested in busses, there's no
+	 * If the user is only interested in buses, there's no
 	 * reason to descend to the next level in the tree.
 	 */
 	if ((retval & DM_RET_ACTION_MASK) == DM_RET_STOP)
@@ -2070,7 +2075,7 @@ xptperiphlistmatch(struct ccb_dev_match 
 
 	/*
 	 * At this point in the edt traversal function, we check the bus
-	 * list generation to make sure that no busses have been added or
+	 * list generation to make sure that no buses have been added or
 	 * removed since the user last sent a XPT_DEV_MATCH ccb through.
 	 * For the peripheral driver list traversal function, however, we
 	 * don't have to worry about new peripheral driver types coming or
@@ -2816,7 +2821,7 @@ call_sim:
 		/*
 		 * There are two ways of getting at information in the EDT.
 		 * The first way is via the primary EDT tree.  It starts
-		 * with a list of busses, then a list of targets on a bus,
+		 * with a list of buses, then a list of targets on a bus,
 		 * then devices/luns on a target, and then peripherals on a
 		 * device/lun.  The "other" way is by the peripheral driver
 		 * lists.  The peripheral driver lists are organized by
@@ -3356,7 +3361,7 @@ xpt_run_devq(struct cam_devq *devq)
 
 		/*
 		 * Device queues can be shared among multiple SIM instances
-		 * that reside on different busses.  Use the SIM from the
+		 * that reside on different buses.  Use the SIM from the
 		 * queued device, rather than the one from the calling bus.
 		 */
 		sim = device->sim;
@@ -3865,7 +3870,7 @@ CAM_XPT_XPORT(xport_default);
  * A sim structure, listing the SIM entry points and instance
  * identification info is passed to xpt_bus_register to hook the SIM
  * into the CAM framework.  xpt_bus_register creates a cam_eb entry
- * for this new bus and places it in the array of busses and assigns
+ * for this new bus and places it in the array of buses and assigns
  * it a path_id.  The path_id may be influenced by "hard wiring"
  * information specified by the user.  Once interrupt services are
  * available, the bus will be probed.
@@ -5040,7 +5045,7 @@ xpt_release_boot(void)
 
 		xsoftc.buses_config_done = 1;
 		xpt_unlock_buses();
-		/* Call manually because we don't have any busses */
+		/* Call manually because we don't have any buses */
 		task = malloc(sizeof(struct xpt_task), M_CAMXPT, M_NOWAIT);
 		if (task != NULL) {
 			TASK_INIT(&task->task, 0, xpt_finishconfig_task, task);
@@ -5138,7 +5143,7 @@ xpt_register_async(int event, ac_callbac
 	    (csa.event_enable & AC_PATH_REGISTERED)) {
 		/*
 		 * Get this peripheral up to date with all
-		 * the currently existing busses.
+		 * the currently existing buses.
 		 */
 		xpt_for_all_busses(xptsetasyncbusfunc, &csa);
 	}

Modified: head/sys/cam/cam_xpt_internal.h
==============================================================================
--- head/sys/cam/cam_xpt_internal.h	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/cam/cam_xpt_internal.h	Sun Jan 15 17:54:01 2017	(r312234)
@@ -88,7 +88,7 @@ SET_DECLARE(cam_xpt_proto_set, struct xp
 
 /*
  * The CAM EDT (Existing Device Table) contains the device information for
- * all devices for all busses in the system.  The table contains a
+ * all devices for all buses in the system.  The table contains a
  * cam_ed structure for each device on the bus.
  */
 struct cam_ed {

Modified: head/sys/dev/bhnd/bhnd.h
==============================================================================
--- head/sys/dev/bhnd/bhnd.h	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/bhnd/bhnd.h	Sun Jan 15 17:54:01 2017	(r312234)
@@ -77,7 +77,7 @@ enum bhnd_device_vars {
  */
 enum {
 	BHND_PROBE_ROOT         = 0,    /**< Nexus or host bridge */
-	BHND_PROBE_BUS		= 1000,	/**< Busses and bridges */
+	BHND_PROBE_BUS		= 1000,	/**< Buses and bridges */
 	BHND_PROBE_CPU		= 2000,	/**< CPU devices */
 	BHND_PROBE_INTERRUPT	= 3000,	/**< Interrupt controllers. */
 	BHND_PROBE_TIMER	= 4000,	/**< Timers and clocks. */

Modified: head/sys/dev/fdt/simplebus.c
==============================================================================
--- head/sys/dev/fdt/simplebus.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/fdt/simplebus.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -125,7 +125,7 @@ simplebus_probe(device_t dev)
 
 	/*
 	 * FDT data puts a "simple-bus" compatible string on many things that
-	 * have children but aren't really busses in our world.  Without a
+	 * have children but aren't really buses in our world.  Without a
 	 * ranges property we will fail to attach, so just fail to probe too.
 	 */
 	if (!(ofw_bus_is_compatible(dev, "simple-bus") &&

Modified: head/sys/dev/isp/isp.c
==============================================================================
--- head/sys/dev/isp/isp.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/isp/isp.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -4396,7 +4396,7 @@ isp_start(XS_T *xs)
 
 	/*
 	 * Now see if we need to synchronize the ISP with respect to anything.
-	 * We do dual duty here (cough) for synchronizing for busses other
+	 * We do dual duty here (cough) for synchronizing for buses other
 	 * than which we got here to send a command to.
 	 */
 	reqp = (ispreq_t *) local;

Modified: head/sys/dev/mmc/mmcreg.h
==============================================================================
--- head/sys/dev/mmc/mmcreg.h	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/mmc/mmcreg.h	Sun Jan 15 17:54:01 2017	(r312234)
@@ -55,7 +55,7 @@
 #define	DEV_MMC_MMCREG_H
 
 /*
- * This file contains the register definitions for the mmc and sd busses.
+ * This file contains the register definitions for the mmc and sd buses.
  * They are taken from publicly available sources.
  */
 

Modified: head/sys/dev/mpt/mpt.c
==============================================================================
--- head/sys/dev/mpt/mpt.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/mpt/mpt.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -1544,7 +1544,7 @@ mpt_get_portfacts(struct mpt_softc *mpt,
 
 /*
  * Send the initialization request. This is where we specify how many
- * SCSI busses and how many devices per bus we wish to emulate.
+ * SCSI buses and how many devices per bus we wish to emulate.
  * This is also the command that specifies the max size of the reply
  * frames from the IOC that we will be allocating.
  */
@@ -1559,7 +1559,7 @@ mpt_send_ioc_init(struct mpt_softc *mpt,
 	init.WhoInit = who;
 	init.Function = MPI_FUNCTION_IOC_INIT;
 	init.MaxDevices = 0;	/* at least 256 devices per bus */
-	init.MaxBuses = 16;	/* at least 16 busses */
+	init.MaxBuses = 16;	/* at least 16 buses */
 
 	init.MsgVersion = htole16(MPI_VERSION);
 	init.HeaderVersion = htole16(MPI_HEADER_VERSION);

Modified: head/sys/dev/mpt/mpt.h
==============================================================================
--- head/sys/dev/mpt/mpt.h	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/mpt/mpt.h	Sun Jan 15 17:54:01 2017	(r312234)
@@ -809,7 +809,7 @@ mpt_read(struct mpt_softc *mpt, int offs
 /*
  * Some operations (e.g. diagnostic register writes while the ARM proccessor
  * is disabled), must be performed using "PCI pio" operations.  On non-PCI
- * busses, these operations likely map to normal register accesses.
+ * buses, these operations likely map to normal register accesses.
  */
 static __inline void
 mpt_pio_write(struct mpt_softc *mpt, size_t offset, uint32_t val)

Modified: head/sys/dev/mpt/mpt_raid.c
==============================================================================
--- head/sys/dev/mpt/mpt_raid.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/mpt/mpt_raid.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -782,7 +782,7 @@ mpt_raid_quiesce_disk(struct mpt_softc *
 }
 #endif
 
-/* XXX Ignores that there may be multiple busses/IOCs involved. */
+/* XXX Ignores that there may be multiple buses/IOCs involved. */
 cam_status
 mpt_map_physdisk(struct mpt_softc *mpt, union ccb *ccb, target_id_t *tgt)
 {
@@ -799,7 +799,7 @@ mpt_map_physdisk(struct mpt_softc *mpt, 
 	return (-1);
 }
 
-/* XXX Ignores that there may be multiple busses/IOCs involved. */
+/* XXX Ignores that there may be multiple buses/IOCs involved. */
 int
 mpt_is_raid_member(struct mpt_softc *mpt, target_id_t tgt)
 {
@@ -818,7 +818,7 @@ mpt_is_raid_member(struct mpt_softc *mpt
 	
 }
 
-/* XXX Ignores that there may be multiple busses/IOCs involved. */
+/* XXX Ignores that there may be multiple buses/IOCs involved. */
 int
 mpt_is_raid_volume(struct mpt_softc *mpt, target_id_t tgt)
 {

Modified: head/sys/dev/pccbb/pccbb_pci.c
==============================================================================
--- head/sys/dev/pccbb/pccbb_pci.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/pccbb/pccbb_pci.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -351,7 +351,7 @@ cbb_pci_attach(device_t brdev)
 	/*
 	 * This is a gross hack.  We should be scanning the entire pci
 	 * tree, assigning bus numbers in a way such that we (1) can
-	 * reserve 1 extra bus just in case and (2) all sub busses
+	 * reserve 1 extra bus just in case and (2) all sub buses
 	 * are in an appropriate range.
 	 */
 	DEVPRINTF((brdev, "Secondary bus is %d\n", sc->bus.sec));

Modified: head/sys/dev/pci/hostb_pci.c
==============================================================================
--- head/sys/dev/pci/hostb_pci.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/pci/hostb_pci.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -37,7 +37,7 @@ __FBSDID("$FreeBSD$");
 
 /*
  * Provide a device to "eat" the host->pci bridge devices that show up
- * on PCI busses and stop them showing up twice on the probes.  This also
+ * on PCI buses and stop them showing up twice on the probes.  This also
  * stops them showing up as 'none' in pciconf -l.  If the host bridge
  * provides an AGP capability then we create a child agp device for the
  * agp GART driver to attach to.

Modified: head/sys/dev/pci/pci.c
==============================================================================
--- head/sys/dev/pci/pci.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/pci/pci.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -3095,7 +3095,7 @@ pci_add_map(device_t bus, device_t dev, 
 	 * If base is 0, then we have problems if this architecture does
 	 * not allow that.  It is best to ignore such entries for the
 	 * moment.  These will be allocated later if the driver specifically
-	 * requests them.  However, some removable busses look better when
+	 * requests them.  However, some removable buses look better when
 	 * all resources are allocated, so allow '0' to be overriden.
 	 *
 	 * Similarly treat maps whose values is the same as the test value
@@ -4178,7 +4178,7 @@ pci_attach(device_t dev)
 
 	/*
 	 * Since there can be multiple independently numbered PCI
-	 * busses on systems with multiple PCI domains, we can't use
+	 * buses on systems with multiple PCI domains, we can't use
 	 * the unit number to decide which bus we are probing. We ask
 	 * the parent pcib what our domain and bus numbers are.
 	 */

Modified: head/sys/dev/pci/pci_private.h
==============================================================================
--- head/sys/dev/pci/pci_private.h	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/pci/pci_private.h	Sun Jan 15 17:54:01 2017	(r312234)
@@ -34,7 +34,7 @@
 
 /*
  * Export definitions of the pci bus so that we can more easily share
- * it with "subclass" busses.
+ * it with "subclass" buses.
  */
 DECLARE_CLASS(pci_driver);
 

Modified: head/sys/dev/pci/pci_subr.c
==============================================================================
--- head/sys/dev/pci/pci_subr.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/pci/pci_subr.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -73,7 +73,7 @@ host_pcib_get_busno(pci_read_config_fn r
 		 * For the 450nx chipset, there is a whole bundle of
 		 * things pretending to be host bridges. The MIOC will 
 		 * be seen first and isn't really a pci bridge (the
-		 * actual busses are attached to the PXB's). We need to 
+		 * actual buses are attached to the PXB's). We need to 
 		 * read the registers of the MIOC to figure out the
 		 * bus numbers for the PXB channels.
 		 *

Modified: head/sys/dev/usb/usb_hub.c
==============================================================================
--- head/sys/dev/usb/usb_hub.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/dev/usb/usb_hub.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -2297,7 +2297,7 @@ usb_needs_explore(struct usb_bus *bus, u
  *	usb_needs_explore_all
  *
  * This function is called whenever a new driver is loaded and will
- * cause that all USB busses are re-explored.
+ * cause that all USB buses are re-explored.
  *------------------------------------------------------------------------*/
 void
 usb_needs_explore_all(void)
@@ -2315,7 +2315,7 @@ usb_needs_explore_all(void)
 		return;
 	}
 	/*
-	 * Explore all USB busses in parallel.
+	 * Explore all USB buses in parallel.
 	 */
 	max = devclass_get_maxunit(dc);
 	while (max >= 0) {

Modified: head/sys/kern/bus_if.m
==============================================================================
--- head/sys/kern/bus_if.m	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/kern/bus_if.m	Sun Jan 15 17:54:01 2017	(r312234)
@@ -206,7 +206,7 @@ METHOD void driver_added {
 /**
  * @brief Create a new child device
  *
- * For busses which use use drivers supporting DEVICE_IDENTIFY() to
+ * For buses which use use drivers supporting DEVICE_IDENTIFY() to
  * enumerate their devices, this method is used to create new
  * device instances. The new device will be added after the last
  * existing child with the same order. Implementations of bus_add_child
@@ -475,7 +475,7 @@ METHOD int teardown_intr {
  * @brief Define a resource which can be allocated with
  * BUS_ALLOC_RESOURCE().
  *
- * This method is used by some busses (typically ISA) to allow a
+ * This method is used by some buses (typically ISA) to allow a
  * driver to describe a resource range that it would like to
  * allocate. The resource defined by @p _type and @p _rid is defined
  * to start at @p _start and to include @p _count indices in its
@@ -562,7 +562,7 @@ METHOD struct resource_list * get_resour
  * should return -1 if it is present.  Any errors in determining
  * should be returned as a normal errno value.  Client drivers are to
  * assume that the device is present, even if there is an error
- * determining if it is there.  Busses are to try to avoid returning
+ * determining if it is there.  Buses are to try to avoid returning
  * errors, but newcard will return an error if the device fails to
  * implement this method.
  * 

Modified: head/sys/kern/sched_ule.c
==============================================================================
--- head/sys/kern/sched_ule.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/kern/sched_ule.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -656,7 +656,7 @@ int __noinline cpu_search_both(const str
  * according to the match argument.  This routine actually compares the
  * load on all paths through the tree and finds the least loaded cpu on
  * the least loaded path, which may differ from the least loaded cpu in
- * the system.  This balances work among caches and busses.
+ * the system.  This balances work among caches and buses.
  *
  * This inline is instantiated in three forms below using constants for the
  * match argument.  It is reduced to the minimum set for each case.  It is

Modified: head/sys/kern/subr_bus.c
==============================================================================
--- head/sys/kern/subr_bus.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/kern/subr_bus.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -1093,7 +1093,7 @@ devclass_driver_added(devclass_t dc, dri
 	int i;
 
 	/*
-	 * Call BUS_DRIVER_ADDED for any existing busses in this class.
+	 * Call BUS_DRIVER_ADDED for any existing buses in this class.
 	 */
 	for (i = 0; i < dc->maxunit; i++)
 		if (dc->devices[i] && device_is_attached(dc->devices[i]))
@@ -3269,7 +3269,7 @@ resource_list_delete(struct resource_lis
 /**
  * @brief Allocate a reserved resource
  *
- * This can be used by busses to force the allocation of resources
+ * This can be used by buses to force the allocation of resources
  * that are always active in the system even if they are not allocated
  * by a driver (e.g. PCI BARs).  This function is usually called when
  * adding a new child to the bus.  The resource is allocated from the
@@ -3648,7 +3648,7 @@ bus_generic_probe(device_t dev)
 		 * only call the identify routines of eligible drivers
 		 * when this routine is called.  Drivers for later
 		 * passes should have their identify routines called
-		 * on early-pass busses during BUS_NEW_PASS().
+		 * on early-pass buses during BUS_NEW_PASS().
 		 */
 		if (dl->pass > bus_current_pass)
 			continue;

Modified: head/sys/sys/bus.h
==============================================================================
--- head/sys/sys/bus.h	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/sys/bus.h	Sun Jan 15 17:54:01 2017	(r312234)
@@ -392,14 +392,14 @@ int	resource_list_print_type(struct reso
 				 const char *format);
 
 /*
- * The root bus, to which all top-level busses are attached.
+ * The root bus, to which all top-level buses are attached.
  */
 extern device_t root_bus;
 extern devclass_t root_devclass;
 void	root_bus_configure(void);
 
 /*
- * Useful functions for implementing busses.
+ * Useful functions for implementing buses.
  */
 
 int	bus_generic_activate_resource(device_t dev, device_t child, int type,
@@ -675,7 +675,7 @@ void	bus_data_generation_update(void);
  * supports the newer ones would return BUS_PROBE_DEFAULT.  BUS_PROBE_GENERIC
  * is for drivers that wish to have a generic form and a specialized form,
  * like is done with the pci bus and the acpi pci bus.  BUS_PROBE_HOOVER is
- * for those busses that implement a generic device place-holder for devices on
+ * for those buses that implement a generic device place-holder for devices on
  * the bus that have no more specific driver for them (aka ugen).
  * BUS_PROBE_NOWILDCARD or lower means that the device isn't really bidding
  * for a device node, but accepts only devices that its parent has told it
@@ -699,7 +699,7 @@ void	bus_data_generation_update(void);
  * probed in earlier passes.
  */
 #define	BUS_PASS_ROOT		0	/* Used to attach root0. */
-#define	BUS_PASS_BUS		10	/* Busses and bridges. */
+#define	BUS_PASS_BUS		10	/* Buses and bridges. */
 #define	BUS_PASS_CPU		20	/* CPU devices. */
 #define	BUS_PASS_RESOURCE	30	/* Resource discovery. */
 #define	BUS_PASS_INTERRUPT	40	/* Interrupt controllers. */
@@ -734,7 +734,7 @@ struct	module;
 int	driver_module_handler(struct module *, int, void *);
 
 /**
- * Module support for automatically adding drivers to busses.
+ * Module support for automatically adding drivers to buses.
  */
 struct driver_module_data {
 	int		(*dmd_chainevh)(struct module *, int, void *);

Modified: head/sys/x86/pci/pci_bus.c
==============================================================================
--- head/sys/x86/pci/pci_bus.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/x86/pci/pci_bus.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -195,7 +195,7 @@ legacy_pcib_is_host_bridge(int bus, int 
 		 * For the 450nx chipset, there is a whole bundle of
 		 * things pretending to be host bridges. The MIOC will
 		 * be seen first and isn't really a pci bridge (the
-		 * actual busses are attached to the PXB's). We need to
+		 * actual buses are attached to the PXB's). We need to
 		 * read the registers of the MIOC to figure out the
 		 * bus numbers for the PXB channels.
 		 *
@@ -566,7 +566,7 @@ legacy_pcib_write_ivar(device_t dev, dev
  *
  * If no memory preference is given, use upper 32MB slot most BIOSes
  * use for their memory window.  This is typically only used on older
- * laptops that don't have PCI busses behind a PCI bridge, so assuming
+ * laptops that don't have PCI buses behind a PCI bridge, so assuming
  * > 32MB is likely OK.
  *	
  * However, this can cause problems for other chipsets, so we make
@@ -723,7 +723,7 @@ DRIVER_MODULE(pcibus_pnp, isa, pcibus_pn
 
 #ifdef __HAVE_PIR
 /*
- * Provide a PCI-PCI bridge driver for PCI busses behind PCI-PCI bridges
+ * Provide a PCI-PCI bridge driver for PCI buses behind PCI-PCI bridges
  * that appear in the PCIBIOS Interrupt Routing Table to use the routing
  * table for interrupt routing when possible.
  */

Modified: head/sys/x86/x86/mptable.c
==============================================================================
--- head/sbin/camcontrol/camcontrol.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sbin/camcontrol/camcontrol.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -3179,8 +3179,8 @@ rescan_or_reset_bus(path_id_t bus, int r
 	/*
 	 * The right way to handle this is to modify the xpt so that it can
 	 * handle a wildcarded bus in a rescan or reset CCB.  At the moment
 	 * that isn't implemented, so instead we enumerate the busses and
 	 * send the rescan or reset to those busses in the case where the
 	 * given bus is -1 (wildcard).  We don't send a rescan or reset
 	 * to the xpt bus; sending a rescan to the xpt bus is effectively a
 	 * no-op, sending a rescan to the xpt bus would result in a status of
@@ -8954,8 +8954,8 @@ usage(int printlong)
 "load        send a Start Unit command to the device with the load bit set\n"
 "eject       send a Stop Unit command to the device with the eject bit set\n"
 "reprobe     update capacity information of the given device\n"
-"rescan      rescan all busses, the given bus, or bus:target:lun\n"
-"reset       reset all busses, the given bus, or bus:target:lun\n"
+"rescan      rescan all buses, the given bus, or bus:target:lun\n"
+"reset       reset all buses, the given bus, or bus:target:lun\n"
 "defects     read the defect list of the specified device\n"
 "modepage    display or edit (-e) the given mode page\n"
 "cmd         send the given SCSI command, may need -i or -o as well\n"
@@ -3179,8 +3179,8 @@ rescan_or_reset_bus(path_id_t bus, int r
 	 * The right way to handle this is to modify the xpt so that it can
 	 * handle a wildcarded bus in a rescan or reset CCB.  At the moment
-	 * that isn't implemented, so instead we enumerate the busses and
-	 * send the rescan or reset to those busses in the case where the
+	 * that isn't implemented, so instead we enumerate the buses and
+	 * send the rescan or reset to those buses in the case where the
 	 * given bus is -1 (wildcard).  We don't send a rescan or reset
 	 * to the xpt bus; sending a rescan to the xpt bus is effectively a

Modified: head/share/man/man4/ehci.4
==============================================================================
--- head/sys/x86/x86/mptable.c	Sun Jan 15 15:43:19 2017	(r312233)
+++ head/sys/x86/x86/mptable.c	Sun Jan 15 17:54:01 2017	(r312234)
@@ -385,7 +385,7 @@ mptable_setup_io(void)
 	for (i = 0; i <= mptable_maxbusid; i++)
 		busses[i].bus_type = NOBUS;
 
 	/* Second, we run through adding I/O APIC's and busses. */
 	mptable_parse_apics_and_busses();	
 
 	/* Third, we run through the table tweaking interrupt sources. */
@@ -584,7 +584,7 @@ mptable_parse_apics_and_busses_handler(u
 }
 
 /*
  * Enumerate I/O APIC's and busses.
  */
 static void
 mptable_parse_apics_and_busses(void)
@@ -988,7 +988,7 @@ mptable_pci_setup(void)
 
 	/*
 	 * Find the first pci bus and call it 0.  Panic if pci0 is not
 	 * bus zero and there are multiple PCI busses.
 	 */
 	for (i = 0; i <= mptable_maxbusid; i++)
 		if (busses[i].bus_type == PCI) {
@@ -996,7 +996,7 @@ mptable_pci_setup(void)
 				pci0 = i;
 			else if (pci0 != 0)
 				panic(
-		"MPTable contains multiple PCI busses but no PCI bus 0");
+		"MPTable contains multiple PCI buses but no PCI bus 0");
 		}
@@ -385,7 +385,7 @@ mptable_setup_io(void)
 		busses[i].bus_type = NOBUS;
 
-	/* Second, we run through adding I/O APIC's and busses. */
+	/* Second, we run through adding I/O APIC's and buses. */
 	mptable_parse_apics_and_busses();	
 
@@ -584,7 +584,7 @@ mptable_parse_apics_and_busses_handler(u
 
 /*
- * Enumerate I/O APIC's and busses.
+ * Enumerate I/O APIC's and buses.
  */
 static void
@@ -988,7 +988,7 @@ mptable_pci_setup(void)
 	/*
 	 * Find the first pci bus and call it 0.  Panic if pci0 is not
-	 * bus zero and there are multiple PCI busses.
+	 * bus zero and there are multiple PCI buses.
 	 */
 	for (i = 0; i <= mptable_maxbusid; i++)

*** DIFF OUTPUT TRUNCATED AT 1000 LINES ***


More information about the svn-src-all mailing list